#ifndef _INBDIEVT_
  #define _INBDIEVT_
/*******************************************************************************
* FILE NAME: inbdievt.hpp                                                      *
*                                                                              *
* DESCRIPTION:                                                                 *
*   Declaration of the class(es):                                              *
*     INotebookDrawItemEvent - Draw-item event class for a notebook page tab   *
*                                                                              *
* COPYRIGHT:                                                                   *
*   Licensed Materials - Property of IBM                                       *
*   (C) Copyright IBM Corporation 1992, 1993                                   *
*   All Rights Reserved                                                        *
*   US Government Users Restricted Rights - Use, duplication, or disclosure    *
*   restricted by GSA ADP Schedule Contract with IBM Corp.                     *
*                                                                              *
*******************************************************************************/
#ifndef _IDIEVT_
  #include <idievt.hpp>
#endif

/*----------------------------------------------------------------------------*/
/* Align classes on four byte boundary.                                       */
/*----------------------------------------------------------------------------*/
#pragma pack(4)

// Forward declarations for other classes:
class IPageHandle;


class INotebookDrawItemEvent : public IDrawItemEvent {
typedef IDrawItemEvent
  Inherited;
/*******************************************************************************
* The INotebookDrawItemEvent class provides event information for drawing a    *
* tab on a notebook page.  This draw-item event is generated only if a         *
* notebook page has a tab that does not have text or a bit map.                *
*******************************************************************************/
public:
/*------------------------------- Constructor ----------------------------------
| The only way to construct instances of this class is from an instance of     |
| the IEvent class.                                                            |
------------------------------------------------------------------------------*/
  INotebookDrawItemEvent ( IEvent& event );

virtual
  INotebookDrawItemEvent :: ~INotebookDrawItemEvent ( );

/*----------------------------- Page Information -------------------------------
| The following function returns information about the notebook page:          |
|   page - Returns a handle to the page whose tab is to be drawn.              |
------------------------------------------------------------------------------*/
virtual IPageHandle
  page                   ( ) const;

/*-------------------------------- Overrrides ----------------------------------
| The following function is overridden to return an identifier for the page:   |
|   itemId - Returns an ID for the page whose tab is to be drawn.  This value  |
|            is used by the page function to return an IPageHandle.            |
------------------------------------------------------------------------------*/
virtual unsigned long
  itemId                 ( ) const;
}; // INotebookDrawItemEvent

/*----------------------------------------------------------------------------*/
/* Resume compiler default packing.                                           */
/*----------------------------------------------------------------------------*/
#pragma pack()

#endif /* _INBDIEVT_ */
